#####################################################################################
#
#		:::[  T h e   R u s s i a n   E g g d r o p  R e s o u r c e  ]::: 
#      ____                __                                                      
#     / __/___ _ ___ _ ___/ /____ ___   ___      ___   ____ ___ _     ____ __ __   
#    / _/ / _ `// _ `// _  // __// _ \ / _ \    / _ \ / __// _ `/    / __// // /   
#   /___/ \_, / \_, / \_,_//_/   \___// .__/ __ \___//_/   \_, / __ /_/   \___/    
#        /___/ /___/                 /_/    /_/           /___/ /_/                
#
#
#####################################################################################
#
# math.tcl 1.3
#
# Description:
#	Displays mathematical calculations.
#
# Installation:
#	1. Make sure you correctly installed egglib_pub.
#	2. Copy math.tcl to scripts/ directory.
#	3. !!! AFTER !!! 'source scripts/egglib_pub.tcl' line in your eggdrop.conf add next:
#		source scripts/math.tcl
#	4. .rehash the bot
#
# Channel flags:
#	.chanset #chan -nopubmath 	- disable usage of !math for #chan
#	.chanset #chan +nopubmath 	- enable usage of !math for #chan
# Authors: Shrike <shrike@eggdrop.org.ru>
#
# Official support: irc.eggdrop.org.ru @ #eggdrop
# 
#####################################################################################
#
# Version History:
#	
#  		SHR - Shrike
#	
#		Who		DATE	Changes
#   	---     ------  -------------------------------------------------------------
# v1.3	SHR		040819	Fixed serious bug. symbol \ was'nt stripeed from input, this
#						make possible execution of commands.
# v1.2			
#   	SHR		040711	Added this header ;)
#						Refacored for namespace usage
#						Rewrited to use socket functions in egglib_pub
#					
#####################################################################################
# Last version of egglib_pub can be grabbed here:
# http://eggdrop.org.ru/scripts/egglib.zip

namespace eval math {}

if { ![info exists egglib(ver)] } {
	putlog "***********************************************"
	putlog "             egglib_pub NOT FOUND !"
	putlog "   Download last version of egglib_pub here:"
	putlog "  http://eggdrop.org.ru/scripts/egglib_pub.zip"
	putlog "***********************************************"	
	die
}

if { [expr {$egglib(ver) < 1.4}] } {
	putlog "***********************************************"
	putlog " YOUR VERSION OF egglib_pub IS TOO OLD !"
	putlog "   Download last version of egglib_pub here:"
	putlog "  http://eggdrop.org.ru/scripts/egglib_pub.zip"
	putlog "***********************************************"
	putlog " version installed : $egglib(ver)"
	putlog " version required: 1.4"
	die
}
   
setudef flag nopubmath

bind pub - !math ::math::pub_math
bind msg - !math ::math::msg_math

set math(ver) 		"1.3"
set math(authors) 	"Shrike <shrike@eggdrop.org.ru>"

proc ::math::pub_math {nick uhost hand chan args} {
	if {[channel get $chan nopubmath]} return
	if { [llength [split [lindex $args 0] ] ] > 1 || [llength [split [lindex $args 0] ] ] == 0 } { set args [split [lindex $args 0]] }
	::math::math $nick $chan $args
}

proc ::math::msg_math {nick uhost hand args} {
	if { [llength [split [lindex $args 0] ] ] > 1 || [llength [split [lindex $args 0] ] ] == 0 } { set args [split [lindex $args 0]] }
	::math::math $nick $nick $args
}

proc ::math::math {nick chan args} {
	if { [llength [split [lindex $args 0] ] ] > 1 || [llength [split [lindex $args 0] ] ] == 0 } { set args [split [lindex $args 0]] }
	regsub -all -- {\}} $args {} args
	regsub -all -- {\{} $args {} args
	regsub -all -- {\]} $args {} args
	regsub -all -- {\[} $args {} args
	regsub -all -- {\$} $args {} args
	regsub -all -- {\\} $args {} args

	set args [::egglib::join_args $args 0 end]
	set pi [expr 2*asin(1.0)]
	
	regsub -all -- {pi} $args {$pi} args1
	
	::egglib::log $chan $nick "math" $args

	if { $args == "" } {
		::egglib::outh $nick $chan "!math" "<>"
		return
	}
	if { [catch { set out [expr $args1] } result] } {
		global errorInfo
		set err $errorInfo
		::egglib::out $nick $chan "$result"
	} else {
		::egglib::out $nick $chan "$args = $out"
	}
}

putlog "msth.tcl v$math(ver) by $math(authors) loaded"


